Crate moirai_core

Crate moirai_core 

Moirai Core

Core abstractions and traits for the Moirai concurrency library.

This crate provides the fundamental building blocks that all other Moirai crates build upon, including task abstractions, executor traits, and scheduling interfaces.

Re-exports

pub use error::ExecutorError;
pub use error::PlacementFailure;
pub use error::SchedulerError;
pub use error::TaskError;
pub use executor::ExecutorConfig;
pub use executor::TaskManager;
pub use executor::TaskSpawner;
pub use executor::TaskStatus;
pub use executor::WorkerPlacement;
pub use scheduler::SchedulerId;
pub use task::Priority;
pub use task::Task;
pub use task::TaskBuilder;
pub use task::TaskContext;
pub use task::TaskExt;
pub use task::TaskFuture;
pub use task::TaskHandle;
pub use task::TaskId;
pub use channel::Channel;
pub use channel::ChannelConfig;
pub use channel::ChannelError;
pub use channel::ChannelStatistics;
pub use channel::Consumer;
pub use channel::DEFAULT_CHANNEL_CAPACITY;
pub use channel::MpmcChannel;
pub use channel::MpmcReceiver;
pub use channel::MpmcSender;
pub use channel::Producer;
pub use channel::Select;
pub use channel::SpscConsumer;
pub use channel::SpscProducer;
pub use channel::SpscReceiver;
pub use channel::SpscRing;
pub use channel::SpscSender;
pub use channel::UnifiedReceiver;
pub use channel::UnifiedSender;
pub use channel::mpmc;
pub use channel::mpmc;
pub use channel::spsc;
pub use channel::spsc;
pub use channel::unified_channel;
pub use channel::unified_channel_with_config;

Modules

channel
Unified high-performance channel implementations for Moirai.
communication
High-performance communication patterns for concurrent systems.
error
Error types and handling for the Moirai runtime.
executor
Executor trait and implementations.
ipc
Same-machine inter-process communication over shared memory.
memory
Advanced memory management for Moirai concurrency library.
platform
Platform abstraction layer for cross-platform compatibility.
pool
Object pooling for efficient memory management.
prelude
Prelude module for convenient imports.
scheduler
Scheduler identity.
task
Task Abstraction Layer

Structs

Arc
A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically Reference Counted’.
Box
A pointer type that uniquely owns a heap allocation of type T.
CacheAligned
A wrapper that pushes its value onto its own false-sharing sector.
String
A UTF-8–encoded, growable string.
Vec
A contiguous growable array type, written as Vec<T>, short for ‘vector’.

Type Aliases

BoxError
Type alias for boxed errors.
Result
Type alias for results with boxed errors.