ExecutorBuilder

Struct ExecutorBuilder 

pub struct ExecutorBuilder { /* private fields */ }
Builder for creating executors with custom configuration.

Implementations

Source

impl ExecutorBuilder

pub fn new() -> Self

Creates a new executor builder with default settings.

Returns

A new builder instance ready for configuration

pub fn worker_threads(self, count: usize) -> Self

Sets the number of worker threads for CPU-bound tasks.

Arguments
  • count - Number of worker threads to create
Returns

The builder instance for method chaining

pub fn worker_placement(self, placement: WorkerPlacement) -> Self

Sets whether each worker is confined to one logical processor.

Arguments
  • placement - The worker placement policy
Returns

The builder instance for method chaining

pub fn async_threads(self, count: usize) -> Self

Sets the number of threads for async task execution.

Arguments
  • count - Number of async threads to create
Returns

The builder instance for method chaining

pub fn max_global_queue_size(self, size: usize) -> Self

Sets the aggregate maximum of the workers’ external admission queues.

Arguments
  • size - Maximum queued tasks across all worker injectors
Returns

The builder instance for method chaining

pub fn local_queue_initial_capacity(self, size: usize) -> Self

Sets the initial capacity of each resizable local priority queue.

Arguments
  • size - Requested initial slots per local priority queue
Returns

The builder instance for method chaining

pub fn thread_name_prefix(self, prefix: impl Into<String>) -> Self

Sets the thread name prefix for executor threads.

Arguments
  • prefix - String prefix for thread names
Returns

The builder instance for method chaining

pub fn preemption_config(self, config: PreemptionConfig) -> Self

Configures preemption behavior for the executor.

Arguments
  • config - Preemption configuration settings
Returns

The builder instance for method chaining

pub fn memory_config(self, config: MemoryConfig) -> Self

Configures memory management settings.

Arguments
  • config - Memory configuration settings
Returns

The builder instance for method chaining

pub fn cleanup_config(self, config: CleanupConfig) -> Self

Configures cleanup and maintenance settings.

Arguments
  • config - Cleanup configuration settings
Returns

The builder instance for method chaining