pub enum IpcError {
SystemError(i32),
InvalidArgument,
AlreadyExists,
EndpointInUse,
NotFound,
PermissionDenied,
}Expand description
IPC-specific error type to minimize dependencies
Variants
SystemError(i32)
System error with error code
InvalidArgument
Invalid argument
AlreadyExists
The name is already taken by a live segment
EndpointInUse
Another handle already holds this endpoint of the queue
NotFound
Resource not found
PermissionDenied
Permission denied